macro_rules! numeric_tuple {
    ($NAME:ident, $TYPE:ty, $ENDIAN:literal, $($DERIVE:ty),* ) => { ... };
}
This is a short hand macro for generateing a new tuple struct type for numerics like u32, i32, u64, i64, f32, f64, … Typically will not be used directly but instead will be called via one of the other macros like u16_tuple, i16_tuple, …